Data models
###########

This reference details the data models used by Canaille.
This is mostly useful for developers.

.. automodule:: canaille.backends.models
    :members:
    :show-inheritance:
    :undoc-members:

.. automodule:: canaille.core.models
    :members:
    :show-inheritance:
    :undoc-members:

.. automodule:: canaille.oidc.basemodels
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: canaille.app.features.Features
    :members:
    :show-inheritance:
    :undoc-members:
